@@ -69,7 +69,11 @@ struct _PlumaTaglistPluginPanelPrivate
 	gchar *data_dir;
 };
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+PLUMA_PLUGIN_DEFINE_TYPE (PlumaTaglistPluginPanel, pluma_taglist_plugin_panel, GTK_TYPE_BOX)
+#else
 PLUMA_PLUGIN_DEFINE_TYPE (PlumaTaglistPluginPanel, pluma_taglist_plugin_panel, GTK_TYPE_VBOX)
+#endif
 
 enum
 {
@@ -641,8 +645,17 @@ add_preview_widget (PlumaTaglistPluginPanel *panel)
 
 	gtk_label_set_line_wrap	(GTK_LABEL (panel->priv->preview), TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (panel->priv->preview), TRUE);
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_widget_set_halign (panel->priv->preview, GTK_ALIGN_START);
+	gtk_widget_set_valign (panel->priv->preview, GTK_ALIGN_START);
+	gtk_widget_set_margin_start (panel->priv->preview, 6);
+	gtk_widget_set_margin_end (panel->priv->preview, 6);
+	gtk_widget_set_margin_top (panel->priv->preview, 6);
+	gtk_widget_set_margin_bottom (panel->priv->preview, 6);
+#else
 	gtk_misc_set_alignment (GTK_MISC (panel->priv->preview), 0, 0);
-	gtk_misc_set_padding (GTK_MISC (panel->priv->preview), 6, 6);	
+	gtk_misc_set_padding (GTK_MISC (panel->priv->preview), 6, 6);
+#endif
 	gtk_label_set_selectable (GTK_LABEL (panel->priv->preview), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (panel->priv->preview), TRUE);
 	gtk_label_set_ellipsize  (GTK_LABEL (panel->priv->preview),
@@ -675,6 +688,11 @@ pluma_taglist_plugin_panel_init (PlumaTaglistPluginPanel *panel)
 	panel->priv = PLUMA_TAGLIST_PLUGIN_PANEL_GET_PRIVATE (panel);
 	panel->priv->data_dir = NULL;
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (panel),
+									GTK_ORIENTATION_VERTICAL);
+#endif
+
 	/* Build the window content */
 	panel->priv->tag_groups_combo = gtk_combo_box_text_new ();
 	gtk_box_pack_start (GTK_BOX (panel),
