@@ -56,6 +56,10 @@
 
 #define PLUMA_VIEW_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), PLUMA_TYPE_VIEW, PlumaViewPrivate))
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
+
 typedef enum
 {
 	GOTO_LINE,
@@ -978,12 +982,16 @@ hide_search_window (PlumaView *view, gboolean cancel)
 static gboolean
 search_entry_flush_timeout (PlumaView *view)
 {
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	GDK_THREADS_ENTER ();
+#endif
 
   	view->priv->typeselect_flush_timeout = 0;
 	hide_search_window (view, FALSE);
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	GDK_THREADS_LEAVE ();
+#endif
 
 	return FALSE;
 }
@@ -1197,11 +1205,15 @@ real_search_enable_popdown (gpointer data)
 {
 	PlumaView *view = (PlumaView *)data;
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	GDK_THREADS_ENTER ();
+#endif
 
 	view->priv->disable_popdown = FALSE;
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	GDK_THREADS_LEAVE ();
+#endif
 
 	return FALSE;
 }
@@ -1528,11 +1540,6 @@ ensure_search_window (PlumaView *view)
 	g_signal_connect (view->priv->search_entry, "activate", 
 			  G_CALLBACK (search_entry_activate),
 			  view);
-	/* CHECK: do we really need to connect to preedit too? -- Paolo
-	g_signal_connect (GTK_ENTRY (view->priv->search_entry)->im_context, "preedit-changed",
-			  G_CALLBACK (gtk_view_search_preedit_changed),
-			  view);
-	*/		
 	g_signal_connect (view->priv->search_entry, 
 			  "insert_text",
 			  G_CALLBACK (search_entry_insert_text), 
@@ -1787,7 +1794,7 @@ start_interactive_search_real (PlumaView *view)
 	    gtk_widget_get_visible (view->priv->search_window))
 		return TRUE;
 
-	if (!gtk_widget_has_focus (view))
+	if (!gtk_widget_has_focus (GTK_WIDGET (view)))
 		return FALSE;
 
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
